pub struct WithMiddleware<E, M>where
E: Endpoint,
M: Middleware,{ /* private fields */ }Expand description
A wrapper that combines an endpoint with middleware.
WithMiddleware allows you to compose an endpoint with middleware to add
cross-cutting concerns like logging, authentication, rate limiting, etc.
The middleware is executed first and can decide whether to call the endpoint
and how to process the response.
Type Parameters
E- The endpoint type that implementsEndpointM- The middleware type that implementsMiddleware
Implementations
Sourceimpl<E, M> WithMiddleware<E, M>where
E: Endpoint,
M: Middleware,
impl<E, M> WithMiddleware<E, M>where
E: Endpoint,
M: Middleware,
Sourcepub fn new(endpoint: E, middleware: M) -> WithMiddleware<E, M>
pub fn new(endpoint: E, middleware: M) -> WithMiddleware<E, M>
Creates a new endpoint that wraps the given endpoint with middleware.
When the resulting endpoint handles a request, the middleware will be executed first. The middleware can then decide whether to call the wrapped endpoint and how to process its response.
Arguments
endpoint- The endpoint to wrapmiddleware- The middleware to apply